@@ -114,8 +114,8 @@ class BaseAPI(ABC):
         return self._inner_apis[dict_key]
 
     @requests_error_handling
-    def _post(self, url: str, data: dict) -> dict:
-        response = self._rally_session.post(url, data=json.dumps(data, default=pydantic_encoder))
+    def _post(self, url: str, data: dict, params: dict = None) -> dict:
+        response = self._rally_session.post(url, data=json.dumps(data, default=pydantic_encoder), params=params)
         rally_raise_errors(response)
         if response.json().get("OperationResult") and response.json().get("OperationResult").get("Object"):
             return response.json()["OperationResult"]["Object"]  # udpate/delete
@@ -218,10 +218,25 @@ class BaseAPI(ABC):
     def _add_members_refs_to_collection(self, parent_ref: str, collection_refs: List[str], collection_name: str):
         url: str = f"{parent_ref}/{collection_name}/add{BaseAPI._security_key}"
         ref_dicts: List[dict] = [{"_ref": ref} for ref in collection_refs]
+        params = {
+            "workspace": self._workspace
+        }
         data = {
             "CollectionItems": ref_dicts
         }
-        self._post(url, data)
+        self._post(url, data, params=params)
+
+
+    def _delete_members_refs_from_collection(self, parent_ref: str, collection_refs: List[str], collection_name: str):
+        url: str = f"{parent_ref}/{collection_name}/remove{BaseAPI._security_key}"
+        ref_dicts: List[dict] = [{"_ref": ref} for ref in collection_refs]
+        params = {
+            "workspace": self._workspace
+        }
+        data = {
+            "CollectionItems": ref_dicts
+        }
+        self._post(url, data, params=params)
 
     def _add_new_members_to_collection(self, parent_ref: str,
                                        member_collection: List[TRallyTypeGeneric],
